@@ -260,7 +260,60 @@ basepath = os.path.expanduser('~/share/bby/')
 #filepath = os.path.join(basepath, 'test.txt')`);
   };
 
+  var sync_bby_lesson = function () {
+    const pathRegRes = /userdata\/lessons-(\d+)-(\w+)\.ipynb/.exec(
+      Jupyter.notebook.notebook_path
+    );
+    const lessonId = Number(pathRegRes[1]);
+    const token = pathRegRes[2];
+    const baseRegRes = /user\/(dev-)?user-(\d+)/.exec(
+      Jupyter.notebook.base_url
+    );
+    const isDev = baseRegRes[1] === 'dev-';
+    const domain = isDev ? 'dev.boyuai.com' : 'boyuai.com';
+
+    const userId = Number(baseRegRes[2]);
+    const body = {
+      content: Jupyter.notebook.toJSON(),
+      userId,
+      token,
+    };
+
+    const path = `/learn/admin/lessons/${lessonId}/jupyter`;
+    $.ajax({
+      url: `https://${domain}/api/v1${path}`,
+      type: 'PUT',
+      dataType: 'json', // Set datatype - affects Accept header
+      data: JSON.stringify(body), // Some data e.g. Valid JSON as a string
+      contentType: 'application/json',
+      success(result) {
+        alert('同步成功，请刷新波波鱼步骤页后查看，中途请不要运行代码');
+      },
+      error() {
+        alert('同步失败');
+      },
+    });
+  };
+
   var addButtons = function () {
+    // 是系统创建的bby lesson，可以同步到波波鱼
+    if (
+      /userdata\/lessons-(\d+)-(\w+)\.ipynb/.test(
+        Jupyter.notebook.notebook_path
+      )
+    ) {
+      Jupyter.toolbar.add_buttons_group([
+        Jupyter.keyboard_manager.actions.register(
+          {
+            help: 'Sync BBY Lesson',
+            icon: 'fa-retweet',
+            handler: sync_bby_lesson,
+          },
+          'sync-lesson',
+          'ipybbycell'
+        ),
+      ]);
+    }
     Jupyter.toolbar.add_buttons_group([
       Jupyter.keyboard_manager.actions.register(
         {
